## Instalacion

1. Creacion del ambiente virtual

   `python -m venv myvenv`

2. Ingresar al ambiente virtual

   `source myvenv/bin/activate`

3. Instalacion de dependencias necesarias

   `pip install -r requirements.txt`
